@@ -2,7 +2,7 @@ import functools
 import logging
 from typing import Dict, List, Callable
 from elasticsearch import Elasticsearch, helpers
-from helper import Result
+from es_orm.helper import Result
 
 
 class ESTypeMapping(object):
